# Hilfe

Hier finden Sie erste Hilfe zur Benutzung von JLU GitLab, aber diese kann [die offizielle Nutzerhilfe (auf Englisch)](https://gitlab.test.uni-giessen.de/help/user/index.md) nicht ersetzen.
Für spezifische Informationen zu JLU GitLab, siehe [Informationen](Informationen.md).

[[_TOC_]]

## Wichtige Konzepte

Git und GitLab sind vielschichtige Werkzeuge mit vielen technischen Konzepten und Begriffen.
Da deren Entwicklung und Namensschöpfung auf Englisch stattfindet, sind diese bisher nur teilweise in andere Sprachen übersetzt worden.
Um die weiteren Hilfestellungen (z.B. bezüglich Lese- und Schreibzugriff) kurz und verständlich zu halten, werden hier die wichtigsten Begriffe allgemeinverständlich erklärt.
Dies ist nur eine gutgemeinte Übersicht; unter [weitere Hilfe](#weitere-hilfe) ist eine Sammlung von Links um sich mit diesen Konzepten vertraut zu machen.

### Git-Begriffe

- [*Git*](https://de.wikipedia.org/wiki/Git) ist der Name einer Software für Versionskontrolle von Dateien.
- Ein *Repository* ist eine Sammlung von Dateien, deren Bearbeitungsverlauf in Schnappschüssen versioniert wird.
  Mit Git kann man beliebig viele unterschiedliche Repositorien verwalten.
- Ein *Commit* ist ein Schnappschuss der Daten im Repository.
  Beim Erstellen eines Commits werden die eingestellte Email-Adresse, der Name, das Datum, die Uhrzeit und ein beliebiges Kommentar untrennbar mit dem Datei-Inhalten der neuen Version verbunden.
  Dies ist eine grundlegende Sicherheitsvorkehrung von Git, um nachträgliche Änderungen dieses Schnappschusses zu verhindern.
  [Lesen Sie hier](#einstellungen-die-private-informationen-betreffen), wie sie diese potentiell privaten Einstellungen ändern können.
- Ein *Branch* ist ein benannter Verlauf von Schnappschüssen, um die Übersichtlichkeit eines Repository zu wahren.
- Die Git-Befehle `pull` und `push` können Branches von Git-Repositorien auf unterschiedlichen Geräten synchronisieren (wie etwa dem eigenen Computer und JLU GitLab).
  Sobald zwei Branches synchronisiert wurden, beinhalten beide eine Kopie aller Daten, d.h. den gesamten Verlauf von Schnappschüssen.

### GitLab-Begriffe

- Ein *Projekt* auf (JLU) GitLab enthält fast immer ein Git-Repository, und bietet viele zusätzliche Funktionen für dessen Verwaltung.
  Zusätzlich bietet GitLab mehrere Systeme um Quellcode eines Projekts automatisch auszuführen, z.B. um Tests auszuführen oder eine Webseite (wie diese) zu erstellen.
- Jedes Projekt ist einem *Namensraum* eines Nutzungskontos oder Nutzergruppe zugeordnet.
  Alle Nutzenden haben jeweils ihren eigenen Namensraum für ihre persönlichen Projekte.
  Genauso haben alle Gruppen jeweils ihren eigenen Namensraum für Gruppenprojekte.
  Ihr Lese- und Schreibzugriff für ein Projekt hängen indirekt von dessen Namensraum ab:
  In Projekten im Namensram von anderen Nutzenden richten Sich Ihre Berechtigungen nach der [Sichtbarkeit des Projekts](#sichtbarkeit-von-projekten), und falls Sie Projektmitglied sind, Ihrer [Nutzerrolle im Projekt](#nutzerrollen-in-projekten).
  In Gruppenprojekten richten sich die Berechtigungen außerdem nach der [Sichtbarkeit der Gruppe](#sichtbarkeit-von-gruppen), und für Gruppenmitglieder sind nach deren [Nutzerrolle in der Gruppe](#nutzerrollen-in-gruppen).
<!--NOTE, nicht nötig?: - Mit einem *Merge-Request* kann man anfragen, einen oder mehrere Commits von einem Git-Repository in ein anderes zu übernehmen. -->


## Wie benutzt man GitLab?

- TODO: Viele Kleinigkeiten mit Browser möglich, für umfangreichere Arbeit aber Git lokal installieren.
- Viele gängige wissenschaftliche Software wie MATLAB, RStudio, usw. verfügen über eine Integration von Git.

Bitte beachten Sie, dass aus dem Internet nur Zugriff per HTTPS möglich ist; Zugriff per SSH ist nur [per VPN](https://www.uni-giessen.de/fbz/svc/hrz/svc/netz/campus/vpn) möglich.


## Wie erstelle ich ein Nutzungskonto?

Zum Anlegen eines JLU GitLab Nutzungskontos wird eine vorhandene g- oder s- Benutzerkennung benötigt.
Informationen zu JLU Benutzerkennungen [finden Sie hier](https://www.uni-giessen.de/fbz/svc/hrz/svc/ident/account?set_language=de).

Mit vorhandener JLU Benutzerkennung wird Ihr Nutzungskonto bei der ersten Anmeldung angelegt, sofern Sie die [Nutzungsbedingungen](Nutzungsbedingungen.md) akzeptieren.
Gehen Sie zur Anmeldung auf https://gitlab.test.uni-giessen.de/ und geben Sie ihre [JLU Benutzerkennung](https://www.uni-giessen.de/fbz/svc/hrz/svc/ident?set_language=de) (g- oder s-Kennung) in das Feld **JLU (g-/s-) Username** und ihr zugehöriges, persönliches Passwort in das Feld **Password** ein.

Nach ihrer ersten Anmeldung werden Ihnen die [Nutzungsbedingungen](Nutzungsbedingungen.md) gezeigt; ihr Nutzungskonto wird nur angelegt, wenn Sie einwilligen.

![Screenshot JLUGitLab Anmeldung](../images/help-login.png)


## Erste Schritte

TODO: Grobe Übersicht, links auf gute Ressourcen zum Weiterlernen ([siehe unten](#weitere-hilfe)).

- Sie können eine für Sie passende Sprache unter [Einstellungen > Profil > Einstellungen > Lokalisierung](https://gitlab.test.uni-giessen.de/profile/preferences#localization) vornehmen.
  Da in GitLab jedoch viele Begriffe nur schwer ins Deutsche zu übersetzen sind, kann es vorkommen, dass Ihnen trotz der korrekten Spracheinstellung viele englischsprachige Begriffe begegnen.

TODO: Link zur Führung in GitLab (oder gibt es die nur in EE?).


## Sichtbarkeit von Projekten

Für jedes Projekt können Sie die Sichtbarkeits-Einstellung *private*, *internal* oder *public* auswählen.
Die Sichtbarkeit kann nur von Nutzenden mit der *Owner*-Rolle im Projekt geändert werden (siehe Nutzerrollen [in Projekten](#nutzerrollen-in-projekten) und [in Gruppen](#nutzerrollen-in-projekten)).

- Projekte mit Sichtbarkeit *private* sind nur für die [Mitglieder des Projekts](#nutzerrollen-in-projekten) einsehbar.
  Für Gruppenprojekte schließt dies die [Gruppenmitglieder](#nutzerrollen-in-gruppen) ein, je nach deren Rolle.
- Projekte mit Sichtbarkeit *internal* sind für alle Personen mit einem Nutzungskonto einsehbar, die angemeldet sind.
  [Bitte lesen Sie hier](Informationen.md#wer-kann-jlu-gitlab-benutzen), auf welchen Personenkreis sich dies bezieht.
- Projekte mit Sichtbarkeit *public* sind für alle Personen ohne Nutzungskonto einsehbar, die auf JLU GitLab zugreifen können.
  [Bitte lesen Sie hier](Informationen.md#wer-kann-auf-jlu-gitlab-zugreifen), auf welchen Personenkreis sich dies bezieht.

Für mehr Details lesen Sie bitte die [offizielle Dokumentation (auf Englisch)](https://gitlab.test.uni-giessen.de/help/public_access/public_access.md#public-access).


## Nutzerrollen in Projekten

Beim Hinzufügen von Projektmitgliedern müssen Sie ihnen bestimmte Rollen zuweisen:
Sie können zwischen *Guest*, *Reporter*, *Developer*, *Maintainer* oder *Owner* auswählen.
Jede dieser Rollen umfasst mehr Berechtigungen als die vorherige, siehe auch in der [offiziellen Dokumentation (auf Englisch)](https://gitlab.test.uni-giessen.de/help/user/permissions.md#project-members-permissions).
Für Projekte im Namensraum einer Gruppe haben die Gruppenmitglieder ihre gleichnamigen [Gruppenrolle](#nutzerrollen-in-gruppen) inne; z.B. ist ein *Guest* in der Gruppe auch ein *Guest* in allen Gruppenprojekten, sofern dies nicht durch individuelle Projektrollen überschrieben ist.
<!-- TODO: Kürzen des Teils auf die notwendigen Hinweise wie "Sei vorsichtig wenn du ein Projekt public machst". Außerdem Hinweise wer für Inhalte in Repos veranwortlich ist mit Bezug auf die Nutzungsbedingungen>
<!-- NOTE: Lass uns unten die Berechtigungen der GitLab.com-Verträgen STARTER, PREMIUM, ULTIMATE weglassen, die nicht Teil der Community Edition sind. -->


### Berechtigungen als *Guest*

Die *Guest*-Rolle ist für nicht-aktive Mitglieder, die einige Inhalte lesen, und Tickets öffnen und kommentieren können.

Projektmitglieder in der *Guest*-Rolle können
das Projekt herunterladen,
Kommentare einbringen,
Projektdateien ansehen und Git-*pull*en,
Wikiseiten ansehen,
neue Tickets erstellen,
verwandte Tickets ansehen,
vertrauliche Tickets erstellen,
und selbsterstellte vertrauliche Tickets ansehen.
Wenn *Öffentliche Pipelines* in den *Projekteinstellungen > CI/CD* aktiviert ist, können sie zusätzlich
eine Liste der Jobs anschauen,
ein Job-Protokoll ansehen,
und Job-Artefakte durchsehen und herunterladen.

### Berechtigungen als *Reporter*

Die *Reporter*-Rolle ist für Mitglieder die mehr Einblick bekommen und im Ticketsystem walten können.
Projektmitglieder mit der *Reporter*-Rolle habe folgende zusätzliche Berechtigungen im Vergleich zur *Guest*-Rolle:

Im Ticketsystem können *Reporter* Tickets zuweisen und
mit Labels versehen,
Kommentare sperren,
und die Ticketliste und Labels verwalten.
*Reporter* können außerdem Codeausschnitte speichern,
den Status eines Commits einsehen,
die Container Registry ansehen,
Umgebungen ansehen,
eine Liste von Merge-Requests ansehen,
Projekt-Statistiken ansehen,
und die Error-Tracking-Liste ansehen.
<!-- NOTE: Error Tracking (keine dt. Übersetzung) ist unter Vorgängen zu finden, man muss mit mit einem Sentry-Server verbinden. -->

### Berechtigungen als *Developer*

Die *Developer*-Rolle ist für Projektmitglieder die aktiv beitragen, und allen nötigen Zugriff haben um eine Idee umzusetzen, solange etwas nicht explizit beschränkt wurde (z.B. durch Branch-Protection).
Projektmitglieder mit der *Developer*-Rolle haben die folgenden zusätzlichen Berechtigungen im Vergleich zur *Reporter*-Rolle:

Im Git-Repository können *Developer* neue Branches anlegen,
und auf nicht-schreibgeschützte Branches *push*en, oder diese löschen.
Sie können neue Merge-Requests anlegen,
bestehende verwalten/akzeptieren,
sie anderen zuweisen und mit Labels versehen,
und deren Kommentarverlauf sperren.
Sie können neue Umgebungen anlegen und diese stoppen.
Zusätzlich können *Developer* Jobs abbrechen und neustarten,
und den Commit-Status anlegen oder aktualisieren.
Sie können die Container-Registry aktualisieren, oder
ein Image in der Container-Registry löschen.
Im Ticketsystem können sie Meilensteine anlegen, bearbeiten, und löschen, und Label hinzufügen.
Sie können Änderungsvorschläge annehmen,
Wikiseiten anlegen und bearbeiten, und
Git-Tags überschreiben/löschen.

### Berechtigungen als *Maintainer*

Die Rolle *Maintainer* ist für Mitglieder die ein Projekt und dessen Mitglieder verwalten.
Projektmitglieder in der *Maintainer*-Rolle bekommen die folgenden zusätzlichen Berechtigungen im Vergliech zur *Developer*-Rolle:

*Maintainer* können neue Projektmitglieder hinzufügen,
Umgebungs-Terminals verwenden,
Branch-Schreibschutz ein/ausschalten,
auf schreibgeschützte Branches *push*en,
den Schreibschutz für *push* durch *Developer* an/ausschalten,
Schreibschutz von Tags an/ausschalten.
*Maintainer* können die Projekteinstellungen bearbeiten,
Deploy-Schlüssel zu dem Projekt hinzufügen,
und Projekt-Hooks konfigurieren.
Sie können Runners verwalten,
Job-Trigger verwalten,
und Umgebungs-Variablen verwalten.
Falls GitLab Pages aktiviert ist, können sie diese verwalten und löschen,
und deren Domains und Zertifikate verwalten.
Sie können Cluster verwalten,
Kommentare von beliebigen Nutzenden bearbeiten,
das Error Tracking verwalten,
und Wikiseiten löschen.
<!-- "Audit-Ereignisse ansehen": Ist nicht in der CE... -->

### Berechtigungen als *Owner*

Nutzende in der *Owner*-Rolle kontrollieren alle Aspekte eines Projekts, inklusive dessen Löschung.
In persönlichen Projekten (im Namensraum eines Nutzungskontos) hat ausschließlich diese Person die *Owner*-Rolle.
In Gruppenprojekten (im Namensraum einer Gruppe) kann es mehrere *Owner* geben, sofern mehrere Gruppenmitglieder die [Gruppenrolle](#group_roles) *Owner* innehaben.
Projektmitglieder in der *Owner*-Rolle haben die folgenden zusätzlichen Berechtigungen im Vergleich zur *Maintainer*-Rolle:

*Owner* können die [Sichtbarkeitsstufe](#visibility_projects) des Projekts ändern,
das Projekt in einen anderen Namensraum transferieren,
das Projekt löschen,
Tickets löschen,
und Benachrichtigungs-Emails ausschalten.

Beachten Sie, dass nach [den Nutzungsbedingungen von JLU GitLab](Nutzungsbedingungen.md) alle Nutzenden mit der *Owner*-Rolle für den Inhalt ihrer Projekte verantwortlich sind, auch wenn diese von anderen Nutzenden stammen.


## Nutzergruppen

Alle Nutzenden könnten *Gruppen* anlegen um mehrere Projekte und Personen zu organisieren.
Beachten Sie, dass [Daten die Sie zu Gruppenprojekten beitragen nicht gelöscht werden](Informationen.md) wenn Sie [die Universität verlassen](Informationen.md) oder [ihr Nutzungskonto löschen](#wie-lösche-ich-mein-nutzungskonto), solange die [Gruppe mindestens ein Mitglied enthält](Informationen.md).

Die Zugriffsrechte eines Projekts im Namensraum einer Gruppe hängt von der [Sichtbarkeit](#sichtbarkeit-von-gruppen) und den [Rollen in der Gruppe](#nutzerrollen-in-gruppen) ab.
Außerdem können individuelle Nutzende auch von außerhalb der Gruppe als Projektmitglied zu individuellen Gruppenprojekten hinzugefügt werden.

### Sichtbarkeit von Gruppen

[Wie die Sichtbarkeit von Projekten](#sichtbarkeit-von-projekten) kann die Sichtbarkeit von Gruppen auf 1) *private*, 2) *internal* oder 3) *public* gesetzt werden, um den Zugriff entweder 1) nur explizit ausgewählten Mitgliedern zu gewähren, oder 2) allen eingeloggten Nutzenden, oder 3) allen Personen, inklusive solchen ohne Nutzungskonto.
[Bitte lesen Sie hier](Informationen.md#wer-kann-jlu-gitlab-benutzen), was die Sichtbarkeitsstufen *internal* und *public* im Fall von JLU GitLab bedeuten.

### Nutzerrollen in Gruppen

Wenn Sie Nutzende als Gruppenmitglieder hinzugefügen, müssen Sie ihnen auch eine Gruppenrolle zuordnen:
Wie die [Nutzerrollen in Projekten](#nutzerrollen-in-projekten) können Sie wählen zwischen *Guest*, *Reporter*, *Developer*, *Maintainer* oder *Owner*.
Die Gruppenrolle eines Mitglieds setzt die Berechtigungen der gleichnamigen [Projekt-Rolle](#nutzerrollen-in-projekten) für alle Gruppenprojekte.
Zusätzlich kann die Projekt-Rolle eines Mitglieds individuell pro Projekt angepasst werden.

Jede Gruppenrolle kommt mit zusätzlichen Berechtigungen innerhalb der Gruppe selbst, siehe auch in der [offiziellen Dokumentation (auf Englisch)](https://gitlab.test.uni-giessen.de/help/user/permissions.md#group-members-permissions):
<!-- NOTE: Let's below exclude the permissions from subscription plans STARTER, PREMIUM, ULTIMATE that are not part of the Community Edition. -->

*Guests* können eine Gruppe nur einsehen, nichts verändern.

*Reporter* können zusätzlich die Gruppen-Label verwalten.

*Developer* können zusätzlich Projekte in der Gruppe anlegen,
und können Meilensteine der Gruppe anlegen/ändern/löschen.

*Maintainer* können zusätzlich Untergruppen anlegen.

*Owners* können zusätzlich die Gruppeneinstellungen ändern,
Gruppenmitglieder verwalten,
die Gruppe löschen,
die Audit Events der Gruppe einsehen,
und Benachrichtigungs-Emails ausschalten.

Beachten Sie, dass nach den [Nutzungsbedingungen von JLU GitLab](Nutzungsbedingungen.md) alle Nutzenden mit der *Owner*-Rolle für den Inhalt ihrer Projekte verantwortlich sind, auch wenn diese von anderen Nutzenden stammen.


## Einstellungen, die private Informationen betreffen

TODO: Beschreibung der Einstellungen von Commit-Namen und -Emailadresse (in GitLab und lokal), Profil und Aktivitäten unsichtbar machen, ...


## Letzte Schritte

Bevor Sie [die Universität verlassen](Informationen.md#was-passiert-wenn-ich-die-jlu-verlasse) oder [Ihr Nutzungskonto löschen](#wie-lösche-ich-mein-nutzungskonto), können Sie einige Optionen bedenken um ihre Projekte zu behalten, oder sie anderen Nutzenden zu übertragen, denn beim Löschen eines Kontos werden auch [alle persönlichen Projekte mitgelöscht](Informationen.md#was-passiert-mit-meinen-daten-wenn-mein-konto-gelöscht-wird).

Bespielsweise werden Sie alle wichtigen Git-Repositorien von JLU GitLab auf Ihren Computer synchronisieren wollen, um Datenverluste zu verhindern.

Um das Löschen eines persönlichen Projekts im eigenen Namensraum zu verhindern, können Sie es in den Namensraum einer anderen Person oder Gruppe transferieren.
Dies muss mit den neuen Eigentümern mit *Owner*-Rolle koordiniert werden.

Sie können Projekte außerdem exportieren; dies erlaubt Ihnen, (nahezu) alle zugehörigen Daten auf eine andere GitLab-Instanz zu übersiedeln.
Im Unterschied zum bloßen Synchronisieren der Git-Repositorien schließt dies auch Tickets, Wiki, usw. mit ein.


## Wie lösche ich mein Nutzungskonto?

Sie können Ihr Nutzungskonto jederzeit löschen, indem Sie [*Einstellungen > Konto > Konto löschen*](https://gitlab.test.uni-giessen.de/profile/account) in ihrem Browser öffnen und mit ihrem Passwort bestätigen.

Bevor Sie Ihr Konto löschen, lesen Sie bitte diese [Übersicht welche Daten mitgelöscht werden](Informationen.md#was-passiert-mit-meinen-daten-wenn-mein-konto-gelöscht-wird);
mit ein paar [letzten Schritten](#letzte-schritte) könnten Sie mögliche Ärgernisse umgehen.

Beachten Sie, dass Sie ihr Konto nicht sofort löschen können, falls Sie die einzige Person mit *Owner*-Rolle in einer Gruppe sind.
In diesem Fall müssen Sie mindestens ein anderes Mitglied als *Owner* einstellen, oder die betreffende Gruppe löschen (z.B. falls Sie das einzige Mitglied sind).


## Weitere Hilfe

TODO: Mehr nützliche Links, evtl. in Kategorien; GitLab selbst hat noch eine Menge.

- [Die offizielle Nutzerhilfe für JLU GitLab (auf Englisch)](https://gitlab.test.uni-giessen.de/help/user/index.md).
- [Kostenloses Online-Buch *Pro Git*](https://git-scm.com/book/de), teilweise auf Deutsch übersetzt

