# Information

[[_TOC_]]


## What is JLU GitLab?

JLU GitLab is a [GitLab web service](https://en.wikipedia.org/wiki/GitLab).
GitLab is a versatile tool for the management of projects that involve file editing.
At the core of each GitLab project is a [Git repository](https://en.wikipedia.org/wiki/Git) that keeps versions of the edited files.
For each project, GitLab also provides a wiki, an issue tracker, and much more.

JLU GitLab is accessible with a web browser at [https://gitlab.test.uni-giessen.de](https://gitlab.test.uni-giessen.de) and is hosted on systems of the [Justus Liebig University (JLU) Giessen](https://www.uni-giessen.de/fbz/svc/hrz).
The deployed GitLab Community Edition is licensed as free software, so JLU GitLab is technically and legally independent from [GitLab.com](https://gitlab.com).

JLU GitLab is maintained by a [team of voluntary employees](#who-is-maintaining-jlu-gitlab).

## Use cases

* In [Good enough practices in scientific computing von G. Wilseon et. al. (2017)](http://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005510) reasons and how to use tools for versioning scientific software and programming code are shown.
* TODO: Add more: lab management, writing and publishing, ...

## No storage of research data

JLU GitLab is currently not suited to store research data.
Such use is explicitly advised against.

For storage of research data, the JLU provides the [JLUbox](https://www.uni-giessen.de/fbz/svc/hrz/svc/daten/jlubox) as well as [network drives](https://www.uni-giessen.de/fbz/svc/hrz/svc/daten/san/index_html).
For questions regarding management of research data, you find further help at [this FAQ](https://www.uni-giessen.de/ub/digitales-publizieren/fdm/faq/) or write an email to [forschungsdaten@uni-giessen.de](mailto:forschungsdaten@uni-giessen.de).


## Who can access JLU GitLab?

JLU GitLab is accessible from the entire Internet (via the HTTPS protocol).

This means that *public* visibility of [projects](Help.md#visibility-of-projects) or [groups](Help.md#visibility-of-groups) applies to anyone with access to the Internet.

Access via the SSH protocol is restricted to the [university VPN](https://www.uni-giessen.de/fbz/svc/hrz/svc/netz/campus/vpn).

## Who may use JLU GitLab?

JLU GitLab is currently usable by all employees and students with a valid g- oder s- JLU account, as long as they accept the [terms of use](TermsOfUse.md).

This means that the *internal* visibility of [projects](Help.md#visibility-of-projects) or [groups](Help.md#visibility-of-groups) applies to all of these people.

You can [read here](Help.md#how-to-register-an-account) how to register an account for JLU GitLab.

## How can I use JLU GitLab?

You can find information on the practical use of JLU GitLab at [help on use](Help.md).

## Account termination

Accounts of JLU GitLab may be terminated in multiple ways:

- Users may voluntarily delete their account at any time. 
  If you want to delete your account, please [follow these steps](Help.md#how-to-delete-my-account).
  You may also consider some [last steps](Help.md#last-steps) before you delete your account.
- The account will be deleted after 6 months after your [g- or s- account becomes invalid](#deletion_account_invalid), which most commonly happens if you [leave the university](#leaving_JLU).
- The [maintainers](#who-is-maintaining-jlu-gitlab) may delete a user account if its activities violate the [terms of use](TermsOfUse.md).

Below you find an [overview what data will also be deleted](#what-happens-to-my-data-when-my-account-is-deleted) when your account gets deleted.

### What happens when I leave JLU?

Once you leave the university (e.g. end of contract, exmatriculation), your [g- or s-account will become invalid](#what-happens-if-my-g-or-s-account-becomes-invalid) within a few weeks.
The [IT service centre](https://www.uni-giessen.de/fbz/svc/hrz) is responsible for this procedure; please contact them if you have questions.

### What happens if my g- or s-account becomes invalid?

If your g- or s-account becomes invalid, your account on JLU GitLab will become blocked automatically within 24 hours.
If your account is blocked, you will not be able to log in to JLU GitLab.
After your account has been blocked for 6 months, it will be deleted, see below.

### What happens to my data when my account is deleted?

How much of your data will be deleted depends on how you used JLU GitLab.
Your account data and personal projects will be deleted (including contained Git repositories).

If you contributed to projects of groups or other users, the association to your account will be removed, but the content will continue to be available to the remaining members.
Your commits to Git repositories of groups or other users (including wikis) will remain unchanged.

#### Deletion of abandoned groups and their projects

Once the last member of a group gets deleted, the group is considered abandoned, and all its associated projects will be deleted as well.

<!-- NOTE, JK: Commented out because it seemed too detailed, but may clarify reasoning.
#### More precise details
To explain more details, the following explanation relies on some [important concepts of Git and GitLab](Help.md#important-concepts).

Once your account is deleted, also all data from your user profile will be deleted, along with all your own projects in your *namespace*.
Note that these projects will be deleted unconditionally, even if they have other project members.
You may take some [last steps](Help.md#last-steps) to avoid possible disruptions.

Data that you contributed to other projects (in namespaces of other users or groups) will not be deleted ([unless a group becomes abandoned](#deletion-of-abandoned-groups-and-their-projects)).
Instead, your contributions will be anonymized as much as is technically possible and acceptable for the remaining members.
This prevents disruption of the remaining members, whose work builds upon your contributions.
For example, the content of your comments in issue trackers of other projects will remain visible, just without a link to your deleted account.
Instead, your comments will appear to be written by a *Ghost* account, which is a placeholder account to manage such anonymized data.

An important exception are your Git *commits* in *repositories* of other projects: They will neither be deleted nor anonymized.
Instead, all information that were used to create the commit will remain as they were; they cannot be altered or deleted without causing disruption for the remaining members.
Also note that your commit data are probably not only saved on JLU GitLab but also on the devices of fellow members, because the Git commands *push* and *pull* can synchronize the entire repository across devices.
JLU GitLab will not (and neither can) delete data from other user's devices.
Importantly, commits may include your real name and email address, depending on the settings of your own device and JLU GitLab.
You can read about [settings concerning your private information](Help.md#settings-concerning-private-information) how to set them up according to your preferences.
--> 

## Who is maintaining JLU GitLab?

JLU GitLab is maintained by a team consisting of volunteers from the faculties and the [university library](https://www.uni-giessen.de/ub/en/), in accordance with the [Guidelines for the IT-system administration at the JLU Giessen (in German)](https://www.uni-giessen.de/fbz/mug/2/pdf/2_26_30_4).
We work in consultation with the [JLU-internal IKM work group](https://www.uni-giessen.de/org/cio/cio/ikm-ag), and for service operations we exclusively use infrastructure of the [IT service centre](https://www.uni-giessen.de/fbz/svc/hrz).

We are always looking for more volunteers who want to join our efforts.
Feel free to contact us if you want to know more about our our way of working and decision process.

You can contact us in various ways, see the [contact information](#contact).

## The goals of JLU GitLab

JLU GitLab first serves to assess demands across the JLU and for evaluation of its features in a research context.
We believe that currently, Git and GitLab provide the best tools to manage and document the software for our research.
Only a locally installed, freely licensed platform like GitLab can ensure our long-term control over its implementation and administration.
<!-- NOTE: Delete, or move to data section and clarify?
Within this context it seems noteworthy that the documentation and software necessary for the understanding of research data are themselves regarded as research data by [JLU's guideline on research data](https://www.uni-giessen.de/mug/5/pdf/forschung/5_00_00_1).
-->

## Future plans

Once JLU GitLab is usable within the university, we have further plans to make it even more useful.
We would like to...

- ...allow accounts for people external to the JLU
- ...investigate the possibility to publish content with [GitLab Pages](https://docs.gitlab.com/ce/user/project/pages/)
- ...evaluate the use of [Git Large File Storage (LFS)](https://docs.gitlab.com/ce/workflow/lfs/manage_large_binaries_with_git_lfs.html)

## Contact

For questions regarding help and support, please write an email to our support mailing list, [gitlab-help@lists.uni-giessen.de](mailto:gitlab-help@lists.uni-giessen.de).

For anything else, can contact the [team of maintainers](#maintainers) at our internal mailing list at [gitlab-admin@lists.uni-giessen.de](mailto:gitlab-admin@lists.uni-giessen.de).

If you want to get receive news about JLU GitLab, you can subscribe to the mailing list [gitlab-news@lists.uni-giessen.de](mailto:gitlab-news@lists.uni-giessen.de).
You can also follow the [protocols of the IKM work group](https://www.uni-giessen.de/org/cio/cio/ikm-ag) (only accessible internally, in German).

